.. sphinx-mcp documentation master file, created by
   sphinx-quickstart on Sat Jul  5 21:22:54 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Example MCP server: ``pymcp``
=============================

``pymcp`` is an open-source template repository for developing MCP servers in Python, using `FastMCP`_. The
project is available on GitHub at `pymcp`_.

.. toctree::
   :maxdepth: 4
   :caption: MCP artefacts

   tools
   prompts
   resources
   resource_templates

.. _FastMCP: http://gofastmcp.com/
.. _pymcp: https://github.com/anirbanbasu/pymcp
